@@ -21,12 +21,40 @@ BEGIN {
 		);
 }
 
-use Cv::Seq::Point;
+#use Cv::Seq::Point;
+#use Cv::Seq::Circle;
 use Cv::Arr;
 our @ISA = qw(Cv::Arr);
 
 sub DESTROY {
 }
 
+sub Pop {
+	my $self = CORE::shift;
+	$self->cvSeqPop;
+}
+
+sub Push {
+	my $self = CORE::shift;
+	eval {
+		$self->cvSeqPush($_) for @_;
+	};
+	if (my $err = $@) {
+		chop($err);
+		$err =~ s/\s*at .* line \d+\.//;
+		croak $err;
+	}
+}
+
+sub Shift {
+	my $self = CORE::shift;
+	$self->cvSeqShift;
+}
+
+sub Unshift {
+	my $self = CORE::shift;
+	$self->cvSeqUnshift($_) for @_;
+}
+
 1;
 __END__
